@@ -43,7 +43,7 @@ import logging
 LOGGER = logging.getLogger('BigML')
 
 from bigml.api import BigML, get_ensemble_id, get_model_id, check_resource
-from bigml.model import Model, retrieve_model, print_distribution
+from bigml.model import Model, retrieve_resource, print_distribution
 from bigml.model import STORAGE, ONLY_MODEL
 from bigml.multivote import MultiVote
 from bigml.multivote import PLURALITY_CODE
@@ -88,8 +88,8 @@ class Ensemble(object):
             self.models_splits = [models[index:(index + max_models)] for index
                                   in range(0, number_of_models, max_models)]
         if len(self.models_splits) == 1:
-            models = [retrieve_model(self.api, model_id,
-                                     query_string=ONLY_MODEL)
+            models = [retrieve_resource(self.api, model_id,
+                                        query_string=ONLY_MODEL)
                       for model_id in self.models_splits[0]]
             self.multi_model = MultiModel(models, self.api)
 
@@ -119,8 +119,8 @@ class Ensemble(object):
             # sequentially used to generate the votes for the prediction
             votes = MultiVote([])
             for models_split in self.models_splits:
-                models = [retrieve_model(self.api, model_id,
-                                         query_string=ONLY_MODEL)
+                models = [retrieve_resource(self.api, model_id,
+                                            query_string=ONLY_MODEL)
                           for model_id in models_split]
                 multi_model = MultiModel(models, api=self.api)
                 votes_split = multi_model.generate_votes(input_data,
